﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace howto_delete_files2
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Add the target folders to the folder text box.
       private void Form1_Load(object sender, EventArgs e)
        {
            string path = Path.GetFullPath(
                Path.Combine(Application.StartupPath, "..\\.."));
            txtFolders.Text =
                path + "\\Targets\r\n" +
                path + "\\Targets\\TargetFolder1\r\n" +
                path + "\\Targets\\TargetFolder2";

            clbFiles.Sorted = true;
            clbFiles.CheckOnClick = true;
        }

        // List the selected files.
        private void btnListFiles_Click(object sender, EventArgs e)
        {
            clbFiles.Items.Clear();

            // Loop through the folders.
            char[] separators = { '\r', '\n' };
            string[] folders = txtFolders.Text.Split(
                separators, StringSplitOptions.RemoveEmptyEntries);
            foreach (string folder in folders)
            {
                // Find files in this folder.
                try
                {
                    DirectoryInfo dir_info = new DirectoryInfo(folder);
                    foreach (FileInfo file_info in dir_info.GetFiles(
                        txtPattern.Text, SearchOption.AllDirectories))
                    {
                        string file_name = file_info.FullName;
                        if (clbFiles.Items.Contains(file_name))
                            Console.WriteLine("Skipped " + file_name);
                        else
                            clbFiles.Items.Add(file_name);
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                }
            }

            // Check all items.
            for (int i = 0; i < clbFiles.Items.Count; i++)
                clbFiles.SetItemChecked(i, true);
            lblNumFiles.Text = clbFiles.Items.Count + " files";
            btnDelete.Enabled = clbFiles.CheckedIndices.Count > 0;
        }

        // Delete the checked files.
        private void btnDelete_Click(object sender, EventArgs e)
        {
            string[] strings = new string[clbFiles.CheckedItems.Count];
            clbFiles.CheckedItems.CopyTo(strings, 0);
            foreach (string file_name in strings)
            {
                Console.WriteLine(file_name);
                try
                {
                    File.Delete(file_name);
                    clbFiles.Items.Remove(file_name);
                }
                catch (Exception ex)
                {
                    Console.WriteLine("Error deleting file. " + ex.Message);
                    if (MessageBox.Show("Error deleting file. " + ex.Message +
                        Environment.NewLine + Environment.NewLine +
                        "Continue?", "Continue?",
                        MessageBoxButtons.YesNo, MessageBoxIcon.Question)
                            == DialogResult.No)
                        break;
                }
            }

            lblNumFiles.Text = clbFiles.CheckedItems.Count + " files";
            btnDelete.Enabled = clbFiles.CheckedItems.Count > 0;
        }

        // Disable the Delete button.
        private void txt_TextChanged(object sender, EventArgs e)
        {
            btnDelete.Enabled = false;
        }

        // Enable the Delete button if any item is checked.
        private void clstFiles_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            int num_checked = clbFiles.CheckedItems.Count;
            if (e.NewValue != e.CurrentValue)
            {
                if (e.NewValue == CheckState.Checked) num_checked++;
                else if (e.NewValue == CheckState.Unchecked) num_checked--;
            }

            lblNumFiles.Text = num_checked + " files";
            btnDelete.Enabled = num_checked > 0;
        }

        // Select all files.
        private void btnAll_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < clbFiles.Items.Count; i++)
                clbFiles.SetItemChecked(i, true);
        }

        private void btnNone_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < clbFiles.Items.Count; i++)
                clbFiles.SetItemChecked(i, false);
        }
    }
}
